# Référence d'erreur

Erreurs courantes :

- `HandlerSignatureError`
- `RouteDefinitionError`

Ligne directrice:

- Corrigez d'abord les signatures du gestionnaire
- Puis valider l'itinéraire DSL et la normalisation
- Réexécuter les tests pour vérifier la régression